@@ -354,12 +354,12 @@ def xhr_save_product(request, pk=None, type=None):
     if f.is_valid():
         product = f.save(commit=False)
         if not pk:
-            product.slug = slugify(request.POST['name'])
+            product.slug = slugify(f.cleaned_data['name'])
             product.num_views = 0
             product.in_date = datetime.datetime.now()
         if product.sold and not product.sold_date:
             product.sold = datetime.date.today()
-        product.live = True
+
         product.save()
 
         return HttpResponse(json.dumps({
@@ -416,6 +416,7 @@ def xhr_products(request):
                 'featured': unicode(form['featured']),
                 'category': unicode(form['category']),
                 'sold': unicode(form['sold']),
+                'live': unicode(form['live']),
             }
         }
         output.append(product_row)
